@@ -1,11 +1,18 @@
 package eris::dictionary::eris;
+# ABSTRACT: Contains fields eris adds to events
 
 use Moo;
 use namespace::autoclean;
 with qw(
     eris::role::dictionary::hash
 );
+
+our $VERSION = '0.004'; # VERSION
+
+
 sub _build_priority { 100; }
+
+
 my $_hash=undef;
 sub hash {
     return $_hash if defined $_hash;
@@ -17,6 +24,8 @@ sub hash {
     }
     $_hash = \%data;
 }
+
+
 1;
 
 =pod
@@ -25,11 +34,27 @@ sub hash {
 
 =head1 NAME
 
-eris::dictionary::eris
+eris::dictionary::eris - Contains fields eris adds to events
 
 =head1 VERSION
 
-version 0.003
+version 0.004
+
+=head1 SYNOPSIS
+
+This dictionary adds fields the L<eris::log::contextualizer> may add to a document.
+
+=head1 ATTRIBUTES
+
+=head2 priority
+
+Defaults to 100, or lastish.
+
+=for Pod::Coverage hash
+
+=head1 SEE ALSO
+
+L<eris::dictionary>, L<eris::role::dictionary>
 
 =head1 AUTHOR
 
@@ -46,10 +71,6 @@ This is free software, licensed under:
 =cut
 
 __DATA__
-source The source of the message
-eris_source Where the eris system contextualized this message
-timestamp The timestamp encoded in the message
-message Message contents, often truncated to relevance.
 referer For web request, the Referrer, note, mispelled as in the RFC
 sld Second-Level Domain, ie what you'd buy on a registrar
 filetype File type or Extension
@@ -62,5 +83,7 @@ dst_user Destination username
 src_geoip GeoIP Data for the source IP
 dst_geoip GeoIP Data for the destination IP
 attacks Attacks root node
+attack_score Total score of all attack detection checks
+attack_triggers Total unique instances of tokens tripping attack checks
 name Name of the event
 class Class of the event
