@@ -1,25 +1,29 @@
 package eris::log::decoder::syslog;
+# ABSTRACT: Parse the syslog headers using Parse::Syslog::Line
 
 use Const::Fast;
 use Moo;
 use Parse::Syslog::Line;
-
 use namespace::autoclean;
 
 with qw(
     eris::role::decoder
 );
 
+our $VERSION = '0.004'; # VERSION
+
+
 # Configure Parse::Syslog::Line
 $Parse::Syslog::Line::DateTimeCreate = 0;
 $Parse::Syslog::Line::EpochCreate    = 1;
 $Parse::Syslog::Line::PruneRaw       = 1;
 $Parse::Syslog::Line::PruneEmpty     = 1;
 @Parse::Syslog::Line::PruneFields    = qw(
-    date time date_str message
+    date time date_str message offset
     preamble facility_int priority_int
 );
 
+
 sub _build_priority { 100; }
 
 # Mappings we need to make
@@ -30,10 +34,12 @@ const my %MAP => (
     host         => 'hostname',
     priority     => 'severity',
     program_name => 'program',
-    program_pid  => 'pid',
+    program_pid  => 'proc_id',
+    program_sub  => 'proc',
     content      => 'message',
 );
 
+
 sub decode_message {
     my ($self,$msg) = @_;
     my %decoded = ();
@@ -47,10 +53,13 @@ sub decode_message {
         }
     };
     return unless exists $decoded{epoch};
+    # Stash this in a safe place
+    $decoded{_epoch} = delete $decoded{epoch};
 
     return \%decoded;
 }
 
+
 1;
 
 __END__
@@ -61,11 +70,36 @@ __END__
 
 =head1 NAME
 
-eris::log::decoder::syslog
+eris::log::decoder::syslog - Parse the syslog headers using Parse::Syslog::Line
 
 =head1 VERSION
 
-version 0.003
+version 0.004
+
+=head1 SYNOPSIS
+
+Uses L<Parse::Syslog::Line> to parse the raw string as if it were a message
+streaming into a syslog server.  This helps capture the meta-data in the syslog
+headers.
+
+=head1 ATTRIBUTES
+
+=head2 priority
+
+Defaults to 100, or last.
+
+=head1 METHODS
+
+=head2 decode_message
+
+Takes a raw string, decodes that message using L<Parse::Syslog::Line> and then
+remaps certain keys to "Common Event Expression" field names.
+
+Stashes the decoded UNIX timestamp into the C<_epoch> key.
+
+=head1 SEE ALSO
+
+L<eris::log::decoders>, L<eris::role::decoder>, L<Parse::Syslog::Line>
 
 =head1 AUTHOR
 
